DAY_CHOICES = (
    (0, "Monday"),
    (1, "Tuesday"),
    (2, "Wednesday"),
    (3, "Thursday"),
    (4, "Friday"),
    (5, "Saturday"),
    (6, "Sunday")
)

BITWISE_DAY_CHOICES = (
    (1, "Sun","Sunday"),
    (2, "Mon","Monday"),
    (4, "Tue","Tuesday"),
    (8, "Wed","Wednesday"),
    (16, "Thu","Thursday"),
    (32, "Fri","Friday"),
    (64, "Sat","Saturday"),
)
